@@ -1,8 +1,6 @@
 import sys
 import typing
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class DataPathBuilder:
     data_path = None
@@ -31,14 +29,6 @@ def classes_recursive(base_type, clss):
     pass
 
 
-def drepr(string):
-    ''' 
-
-    '''
-
-    pass
-
-
 def find_path_new(id_data, data_path, rna_update_from_map, fcurve, log):
     ''' 
 
