@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class ModifierButtonsPanel:
     bl_context = None
@@ -66,7 +64,7 @@ class DATA_PT_gpencil_modifiers(ModifierButtonsPanel, bpy_types.Panel,
         '''
         pass
 
-    def draw(self, context):
+    def draw(self, _context):
         ''' 
 
         '''
@@ -252,7 +250,7 @@ class DATA_PT_modifiers(ModifierButtonsPanel, bpy_types.Panel,
         '''
         pass
 
-    def draw(self, context):
+    def draw(self, _context):
         ''' 
 
         '''
