@@ -52,8 +52,8 @@ class VOLUME_UL_grids(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_item(self, context, layout, data, grid, icon, active_data,
-                  active_propname, index):
+    def draw_item(self, _context, layout, _data, grid, _icon, _active_data,
+                  _active_propname, _index):
         ''' 
 
         '''
