@@ -58,6 +58,18 @@ class PHYSICS_PT_add(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -94,6 +106,12 @@ class PHYSICS_PT_add(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -148,12 +166,24 @@ class PHYSICS_PT_add(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -179,7 +209,7 @@ class PHYSICS_PT_add(PhysicButtonsPanel, bpy_types.Panel,
         pass
 
 
-def basic_force_field_falloff_ui(context, field):
+def basic_force_field_falloff_ui(field):
     ''' 
 
     '''
@@ -187,7 +217,7 @@ def basic_force_field_falloff_ui(context, field):
     pass
 
 
-def basic_force_field_settings_ui(context, field):
+def basic_force_field_settings_ui(field):
     ''' 
 
     '''
@@ -195,7 +225,7 @@ def basic_force_field_settings_ui(context, field):
     pass
 
 
-def effector_weights_ui(context, weights, weight_type):
+def effector_weights_ui(weights, weight_type):
     ''' 
 
     '''
@@ -219,7 +249,7 @@ def physics_add_special(layout, data, name, addop, removeop, typeicon):
     pass
 
 
-def point_cache_ui(context, cache, enabled, cachetype):
+def point_cache_ui(cache, enabled, cachetype):
     ''' 
 
     '''
