@@ -34,8 +34,8 @@ class VIEWLAYER_UL_aov(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname):
+    def draw_item(self, _context, layout, _data, item, icon, _active_data,
+                  _active_propname):
         ''' 
 
         '''
