@@ -1,13 +1,11 @@
 import sys
 import typing
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def aspect(fontid: int, aspect: float):
     ''' Set the aspect for drawing text.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param aspect: The aspect ratio for text drawing to use.
     :type aspect: float
@@ -19,7 +17,7 @@ def aspect(fontid: int, aspect: float):
 def clipping(fontid: int, xmin: float, ymin: float, xmax: float, ymax: float):
     ''' Set the clipping, enable/disable using CLIPPING.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param xmin: Clip the drawing area by these bounds.
     :type xmin: float
@@ -37,7 +35,7 @@ def clipping(fontid: int, xmin: float, ymin: float, xmax: float, ymax: float):
 def color(fontid: int, r: float, g: float, b: float, a: float):
     ''' Set the color for drawing text.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param r: red channel 0.0 - 1.0.
     :type r: float
@@ -52,14 +50,13 @@ def color(fontid: int, r: float, g: float, b: float, a: float):
     pass
 
 
-def dimensions(fontid: int, text: str) -> typing.Tuple:
+def dimensions(fontid: int, text: str) -> tuple:
     ''' Return the width and height of the text.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param text: the text to draw.
     :type text: str
-    :rtype: typing.Tuple
     :return: the width and height of the text.
     '''
 
@@ -69,7 +66,7 @@ def dimensions(fontid: int, text: str) -> typing.Tuple:
 def disable(fontid: int, option: int):
     ''' Disable option.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param option: One of ROTATION, CLIPPING, SHADOW or KERNING_DEFAULT.
     :type option: int
@@ -81,7 +78,7 @@ def disable(fontid: int, option: int):
 def draw(fontid: int, text: str):
     ''' Draw text in the current context.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param text: the text to draw.
     :type text: str
@@ -93,7 +90,7 @@ def draw(fontid: int, text: str):
 def enable(fontid: int, option: int):
     ''' Enable option.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param option: One of ROTATION, CLIPPING, SHADOW or KERNING_DEFAULT.
     :type option: int
@@ -102,12 +99,11 @@ def enable(fontid: int, option: int):
     pass
 
 
-def load(filename: str) -> typing.Any:
+def load(filename: str):
     ''' Load a new font.
 
     :param filename: the filename of the font.
     :type filename: str
-    :rtype: typing.Any
     :return: the new font's fontid or -1 if there was an error.
     '''
 
@@ -117,7 +113,7 @@ def load(filename: str) -> typing.Any:
 def position(fontid: int, x: float, y: float, z: float):
     ''' Set the position for drawing text.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param x: X axis position to draw the text.
     :type x: float
@@ -133,7 +129,7 @@ def position(fontid: int, x: float, y: float, z: float):
 def rotation(fontid: int, angle: float):
     ''' Set the text rotation angle, enable/disable using ROTATION.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param angle: The angle for text drawing to use.
     :type angle: float
@@ -145,7 +141,7 @@ def rotation(fontid: int, angle: float):
 def shadow(fontid: int, level: int, r: float, g: float, b: float, a: float):
     ''' Shadow options, enable/disable using SHADOW .
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param level: The blur level, can be 3, 5 or 0.
     :type level: int
@@ -165,7 +161,7 @@ def shadow(fontid: int, level: int, r: float, g: float, b: float, a: float):
 def shadow_offset(fontid: int, x: float, y: float):
     ''' Set the offset for shadow text.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param x: Vertical shadow offset value in pixels.
     :type x: float
@@ -179,7 +175,7 @@ def shadow_offset(fontid: int, x: float, y: float):
 def size(fontid: int, size: int, dpi: int):
     ''' Set the size and dpi for drawing text.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param size: Point size of the font.
     :type size: int
@@ -203,7 +199,7 @@ def unload(filename: str):
 def word_wrap(fontid: int, wrap_width: int):
     ''' Set the wrap width, enable/disable using WORD_WRAP.
 
-    :param fontid: `blf.load`, for default font use 0.
+    :param fontid: blf.load , for default font use 0.
     :type fontid: int
     :param wrap_width: The width (in pixels) to wrap words at.
     :type wrap_width: int
