@@ -34,7 +34,6 @@ def beautify_fill(
     :type use_restrict_tag: bool
     :param method: method to define what is beautiful
     :type method: typing.Union[str, int]
-    :rtype: dict
     :return: - geom : new flipped faces and edges **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -42,8 +41,8 @@ def beautify_fill(
 
 
 def bevel(bm: 'bmesh.types.BMesh', geom: typing.
-          Union[typing.List['bmesh.types.BMVert'], typing.
-                List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']],
+          Union[typing.List['bmesh.types.BMFace'], typing.
+                List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']],
           offset: float, offset_type: typing.Union[str, int],
           profile_type: typing.Union[str, int], segments: int, profile: float,
           affect: typing.Union[str, int], clamp_overlap: bool, material: int,
@@ -58,7 +57,7 @@ def bevel(bm: 'bmesh.types.BMesh', geom: typing.
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input edges and vertices
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param offset: amount to offset beveled edge
     :type offset: float
     :param offset_type: how to measure the offset
@@ -97,7 +96,6 @@ def bevel(bm: 'bmesh.types.BMesh', geom: typing.
     :type custom_profile: 'bpy.types.bpy_struct'
     :param vmesh_method: The method to use to create meshes at intersections.
     :type vmesh_method: typing.Union[str, int]
-    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace ) - edges : output edges **type** list of ( bmesh.types.BMEdge ) - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -117,7 +115,6 @@ def bisect_edges(bm: 'bmesh.types.BMesh',
     :type cuts: int
     :param edge_percents: Undocumented.
     :type edge_percents: dict
-    :rtype: dict
     :return: - geom_split : newly created vertices and edges **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -126,8 +123,8 @@ def bisect_edges(bm: 'bmesh.types.BMesh',
 
 def bisect_plane(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMVert'], typing.
-              List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']],
+        Union[typing.List['bmesh.types.BMFace'], typing.
+              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']],
         dist: float, plane_co: typing.List['mathutils.Vector'],
         plane_no: typing.List['mathutils.Vector'], use_snap_center: bool,
         clear_outer: bool, clear_inner: bool) -> dict:
@@ -136,7 +133,7 @@ def bisect_plane(
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param dist: minimum distance when testing if a vert is exactly on the plane
     :type dist: float
     :param plane_co: point on the plane
@@ -149,7 +146,6 @@ def bisect_plane(
     :type clear_outer: bool
     :param clear_inner: when enabled. remove all geometry on the negative side of the plane
     :type clear_inner: bool
-    :rtype: dict
     :return: - geom_cut : output geometry aligned with the plane (new and existing) **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge ) - geom : input and output geometry (result of cut) **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -191,7 +187,6 @@ def bridge_loops(bm: 'bmesh.types.BMesh',
     :type merge_factor: float
     :param twist_offset: twist offset for closed loops
     :type twist_offset: int
-    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace ) - edges : new edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -240,7 +235,6 @@ def connect_vert_pair(
     :type verts_exclude: typing.List['bmesh.types.BMVert']
     :param faces_exclude: input faces to explicitly exclude from connecting
     :type faces_exclude: typing.List['bmesh.types.BMFace']
-    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -261,7 +255,6 @@ def connect_verts(bm: 'bmesh.types.BMesh',
     :type faces_exclude: typing.List['bmesh.types.BMFace']
     :param check_degenerate: prevent splits with overlaps & intersections
     :type check_degenerate: bool
-    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -276,7 +269,6 @@ def connect_verts_concave(bm: 'bmesh.types.BMesh',
     :type bm: 'bmesh.types.BMesh'
     :param faces: input faces
     :type faces: typing.List['bmesh.types.BMFace']
-    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge ) - faces : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -293,7 +285,6 @@ def connect_verts_nonplanar(bm: 'bmesh.types.BMesh', angle_limit: float,
     :type angle_limit: float
     :param faces: input faces
     :type faces: typing.List['bmesh.types.BMFace']
-    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge ) - faces : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -302,20 +293,19 @@ def connect_verts_nonplanar(bm: 'bmesh.types.BMesh', angle_limit: float,
 
 def contextual_create(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMVert'], typing.
-              List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']],
+        Union[typing.List['bmesh.types.BMFace'], typing.
+              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']],
         mat_nr: int, use_smooth: bool) -> dict:
     ''' Contextual Create. This is basically F-key, it creates new faces from vertices, makes stuff from edge nets, makes wire edges, etc. It also dissolves faces. Three verts become a triangle, four become a quad. Two become a wire edge.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry.
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param mat_nr: material to use
     :type mat_nr: int
     :param use_smooth: smooth to use
     :type use_smooth: bool
-    :rtype: dict
     :return: - faces : newly-made face(s) **type** list of ( bmesh.types.BMFace ) - edges : newly-made edge(s) **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -323,8 +313,8 @@ def contextual_create(
 
 
 def convex_hull(bm: 'bmesh.types.BMesh',
-                input: typing.Union[typing.List['bmesh.types.BMVert'], typing.
-                                    List['bmesh.types.BMFace'], typing.
+                input: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                    List['bmesh.types.BMVert'], typing.
                                     List['bmesh.types.BMEdge']],
                 use_existing_faces: bool) -> dict:
     ''' Convex Hull Builds a convex hull from the vertices in 'input'. If 'use_existing_faces' is true, the hull will not output triangles that are covered by a pre-existing face. All hull vertices, faces, and edges are added to 'geom.out'. Any input elements that end up inside the hull (i.e. are not used by an output face) are added to the 'interior_geom' slot. The 'unused_geom' slot will contain all interior geometry that is completely unused. Lastly, 'holes_geom' contains edges and faces that were in the input and are part of the hull.
@@ -332,10 +322,9 @@ def convex_hull(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: input geometry
-    :type input: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type input: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param use_existing_faces: skip hull triangles that are covered by a pre-existing face
     :type use_existing_faces: bool
-    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_interior : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_unused : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_holes : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -361,7 +350,6 @@ def create_circle(bm: 'bmesh.types.BMesh', cap_ends: bool, cap_tris: bool,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -392,7 +380,6 @@ def create_cone(bm: 'bmesh.types.BMesh', cap_ends: bool, cap_tris: bool,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -411,7 +398,6 @@ def create_cube(bm: 'bmesh.types.BMesh', size: float,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -435,7 +421,6 @@ def create_grid(bm: 'bmesh.types.BMesh', x_segments: int, y_segments: int,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -457,7 +442,6 @@ def create_icosphere(bm: 'bmesh.types.BMesh', subdivisions: int,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -474,7 +458,6 @@ def create_monkey(bm: 'bmesh.types.BMesh', matrix: 'mathutils.Matrix',
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -498,7 +481,6 @@ def create_uvsphere(bm: 'bmesh.types.BMesh', u_segments: int, v_segments: int,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -513,7 +495,6 @@ def create_vert(bm: 'bmesh.types.BMesh',
     :type bm: 'bmesh.types.BMesh'
     :param co: the coordinate of the new vert
     :type co: typing.List['mathutils.Vector']
-    :rtype: dict
     :return: - vert : the new vert **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -521,8 +502,8 @@ def create_vert(bm: 'bmesh.types.BMesh',
 
 
 def delete(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
-                              List['bmesh.types.BMFace'], typing.
+           geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                              List['bmesh.types.BMVert'], typing.
                               List['bmesh.types.BMEdge']],
            context: typing.Union[str, int]):
     ''' Delete Geometry. Utility operator to delete geometry.
@@ -530,7 +511,7 @@ def delete(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param context: geometry types to delete
     :type context: typing.Union[str, int]
     '''
@@ -566,7 +547,6 @@ def dissolve_edges(bm: 'bmesh.types.BMesh',
     :type use_verts: bool
     :param use_face_split: split off face corners to maintain surrounding geometry
     :type use_face_split: bool
-    :rtype: dict
     :return: - region : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -584,7 +564,6 @@ def dissolve_faces(bm: 'bmesh.types.BMesh',
     :type faces: typing.List['bmesh.types.BMFace']
     :param use_verts: dissolve verts left between only 2 edges.
     :type use_verts: bool
-    :rtype: dict
     :return: - region : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -610,7 +589,6 @@ def dissolve_limit(bm: 'bmesh.types.BMesh', angle_limit: float,
     :type edges: typing.List['bmesh.types.BMEdge']
     :param delimit: delimit dissolve operation
     :type delimit: set
-    :rtype: dict
     :return: - region : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -636,8 +614,8 @@ def dissolve_verts(bm: 'bmesh.types.BMesh',
 
 
 def duplicate(bm: 'bmesh.types.BMesh',
-              geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
-                                 List['bmesh.types.BMFace'], typing.
+              geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                 List['bmesh.types.BMVert'], typing.
                                  List['bmesh.types.BMEdge']],
               dest: 'bmesh.types.BMesh', use_select_history: bool,
               use_edge_flip_from_face: bool) -> dict:
@@ -646,14 +624,13 @@ def duplicate(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param dest: destination bmesh, if NULL will use current on
     :type dest: 'bmesh.types.BMesh'
     :param use_select_history: Undocumented.
     :type use_select_history: bool
     :param use_edge_flip_from_face: Undocumented.
     :type use_edge_flip_from_face: bool
-    :rtype: dict
     :return: - geom_orig : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - vert_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - edge_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - face_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - boundary_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - isovert_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -673,7 +650,6 @@ def edgeloop_fill(bm: 'bmesh.types.BMesh',
     :type mat_nr: int
     :param use_smooth: smooth state to use
     :type use_smooth: bool
-    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -695,7 +671,6 @@ def edgenet_fill(bm: 'bmesh.types.BMesh',
     :type use_smooth: bool
     :param sides: number of sides
     :type sides: int
-    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -704,13 +679,12 @@ def edgenet_fill(bm: 'bmesh.types.BMesh',
 
 def edgenet_prepare(bm: 'bmesh.types.BMesh',
                     edges: typing.List['bmesh.types.BMEdge']) -> dict:
-    ''' Edgenet Prepare. Identifies several useful edge loop cases and modifies them so they'll become a face when edgenet_fill is called. The cases covered are: - One single loop; an edge is added to connect the ends - Two loops; two edges are added to connect the endpoints (based on the shortest distance between each endpont).
+    ''' Edgenet Prepare. Identifies several useful edge loop cases and modifies them so they'll become a face when edgenet_fill is called. The cases covered are: - One single loop; an edge is added to connect the ends - Two loops; two edges are added to connect the endpoints (based on the shortest distance between each endpoint).
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param edges: input edges
     :type edges: typing.List['bmesh.types.BMEdge']
-    :rtype: dict
     :return: - edges : new edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -730,7 +704,6 @@ def extrude_discrete_faces(
     :type use_normal_flip: bool
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
-    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -750,7 +723,6 @@ def extrude_edge_only(bm: 'bmesh.types.BMesh',
     :type use_normal_flip: bool
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
-    :rtype: dict
     :return: - geom : output geometry **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -759,8 +731,8 @@ def extrude_edge_only(bm: 'bmesh.types.BMesh',
 
 def extrude_face_region(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMVert'], typing.
-              List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']],
+        Union[typing.List['bmesh.types.BMFace'], typing.
+              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']],
         edges_exclude: set, use_keep_orig: bool, use_normal_flip: bool,
         use_normal_from_adjacent: bool, use_dissolve_ortho_edges: bool,
         use_select_history: bool) -> dict:
@@ -769,7 +741,7 @@ def extrude_face_region(
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: edges and faces
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param edges_exclude: input edges to explicitly exclude from extrusion
     :type edges_exclude: set
     :param use_keep_orig: keep original geometry (requires geom to include edges).
@@ -782,7 +754,6 @@ def extrude_face_region(
     :type use_dissolve_ortho_edges: bool
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
-    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -800,7 +771,6 @@ def extrude_vert_indiv(bm: 'bmesh.types.BMesh',
     :type verts: typing.List['bmesh.types.BMVert']
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
-    :rtype: dict
     :return: - edges : output wire edges **type** list of ( bmesh.types.BMEdge ) - verts : output vertices **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -820,7 +790,6 @@ def face_attribute_fill(bm: 'bmesh.types.BMesh',
     :type use_normals: bool
     :param use_data: copy face data
     :type use_data: bool
-    :rtype: dict
     :return: - faces_fail : faces that could not be handled **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -840,7 +809,6 @@ def find_doubles(
     :type keep_verts: typing.List['bmesh.types.BMVert']
     :param dist: maximum distance
     :type dist: float
-    :rtype: dict
     :return: - targetmap : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -862,7 +830,6 @@ def grid_fill(bm: 'bmesh.types.BMesh',
     :type use_smooth: bool
     :param use_interp_simple: use simple interpolation
     :type use_interp_simple: bool
-    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -879,7 +846,6 @@ def holes_fill(bm: 'bmesh.types.BMesh',
     :type edges: typing.List['bmesh.types.BMEdge']
     :param sides: number of face sides to fill
     :type sides: int
-    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -906,7 +872,6 @@ def inset_individual(bm: 'bmesh.types.BMesh',
     :type use_interpolate: bool
     :param use_relative_offset: scale the offset by surrounding geometry
     :type use_relative_offset: bool
-    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -943,7 +908,6 @@ def inset_region(
     :type depth: float
     :param use_outset: outset rather than inset
     :type use_outset: bool
-    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -975,7 +939,6 @@ def join_triangles(bm: 'bmesh.types.BMesh',
     :type angle_face_threshold: float
     :param angle_shape_threshold: Undocumented.
     :type angle_shape_threshold: float
-    :rtype: dict
     :return: - faces : joined faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -1000,8 +963,8 @@ def mesh_to_bmesh(bm: 'bmesh.types.BMesh', mesh: 'bpy.types.Mesh',
 
 
 def mirror(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
-                              List['bmesh.types.BMFace'], typing.
+           geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                              List['bmesh.types.BMVert'], typing.
                               List['bmesh.types.BMEdge']],
            matrix: 'mathutils.Matrix', merge_dist: float,
            axis: typing.Union[str, int], mirror_u: bool, mirror_v: bool,
@@ -1011,7 +974,7 @@ def mirror(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param matrix: matrix defining the mirror transformation
     :type matrix: 'mathutils.Matrix'
     :param merge_dist: maximum distance for merging. does no merging if 0.
@@ -1026,7 +989,6 @@ def mirror(bm: 'bmesh.types.BMesh',
     :type mirror_udim: bool
     :param use_shapekey: Transform shape keys too.
     :type use_shapekey: bool
-    :rtype: dict
     :return: - geom : output geometry, mirrored **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1059,7 +1021,6 @@ def offset_edgeloops(bm: 'bmesh.types.BMesh',
     :type edges: typing.List['bmesh.types.BMEdge']
     :param use_cap_endpoint: extend loop around end-points
     :type use_cap_endpoint: bool
-    :rtype: dict
     :return: - edges : output edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -1079,7 +1040,6 @@ def planar_faces(bm: 'bmesh.types.BMesh',
     :type iterations: int
     :param factor: Influence for making planar each iteration
     :type factor: float
-    :rtype: dict
     :return: - geom : output slot, computed boundary geometry. **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1133,7 +1093,6 @@ def poke(bm: 'bmesh.types.BMesh', faces: typing.List['bmesh.types.BMFace'],
     :type center_mode: typing.Union[str, int]
     :param use_relative_offset: apply offset
     :type use_relative_offset: bool
-    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert ) - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -1155,22 +1114,21 @@ def recalc_face_normals(bm: 'bmesh.types.BMesh',
 
 def region_extend(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMVert'], typing.
-              List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']],
+        Union[typing.List['bmesh.types.BMFace'], typing.
+              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']],
         use_contract: bool, use_faces: bool, use_face_step: bool) -> dict:
     ''' Region Extend. used to implement the select more/less tools. this puts some geometry surrounding regions of geometry in geom into geom.out. if use_faces is 0 then geom.out spits out verts and edges, otherwise it spits out faces.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param use_contract: find boundary inside the regions, not outside.
     :type use_contract: bool
     :param use_faces: extend from faces instead of edges
     :type use_faces: bool
     :param use_face_step: step over connected faces
     :type use_face_step: bool
-    :rtype: dict
     :return: - geom : output slot, computed boundary geometry. **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1283,7 +1241,6 @@ def rotate_edges(bm: 'bmesh.types.BMesh',
     :type edges: typing.List['bmesh.types.BMEdge']
     :param use_ccw: rotate edge counter-clockwise if true, otherwise clockwise
     :type use_ccw: bool
-    :rtype: dict
     :return: - edges : newly spun edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -1385,8 +1342,8 @@ def smooth_vert(bm: 'bmesh.types.BMesh',
 
 
 def solidify(bm: 'bmesh.types.BMesh',
-             geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
-                                List['bmesh.types.BMFace'], typing.
+             geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                List['bmesh.types.BMVert'], typing.
                                 List['bmesh.types.BMEdge']],
              thickness: float) -> dict:
     ''' Solidify. Turns a mesh into a shell with thickness
@@ -1394,10 +1351,9 @@ def solidify(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param thickness: thickness
     :type thickness: float
-    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1405,8 +1361,8 @@ def solidify(bm: 'bmesh.types.BMesh',
 
 
 def spin(bm: 'bmesh.types.BMesh', geom: typing.
-         Union[typing.List['bmesh.types.BMVert'], typing.
-               List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']],
+         Union[typing.List['bmesh.types.BMFace'], typing.
+               List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']],
          cent: typing.List['mathutils.Vector'],
          axis: typing.List['mathutils.Vector'],
          dvec: typing.List['mathutils.Vector'], angle: float,
@@ -1417,7 +1373,7 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param cent: rotation center
     :type cent: typing.List['mathutils.Vector']
     :param axis: rotation axis
@@ -1436,7 +1392,6 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
     :type use_normal_flip: bool
     :param use_duplicate: duplicate or extrude?
     :type use_duplicate: bool
-    :rtype: dict
     :return: - geom_last : result of last step **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1444,20 +1399,19 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
 
 
 def split(bm: 'bmesh.types.BMesh', geom: typing.
-          Union[typing.List['bmesh.types.BMVert'], typing.
-                List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']],
+          Union[typing.List['bmesh.types.BMFace'], typing.
+                List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']],
           dest: 'bmesh.types.BMesh', use_only_faces: bool) -> dict:
     ''' Split Off Geometry. Disconnect geometry from adjacent edges and faces, optionally into a destination mesh.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param dest: destination bmesh, if NULL will use current one
     :type dest: 'bmesh.types.BMesh'
     :param use_only_faces: when enabled. don't duplicate loose verts/edges
     :type use_only_faces: bool
-    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - boundary_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - isovert_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -1477,7 +1431,6 @@ def split_edges(
     :type verts: typing.List['bmesh.types.BMVert']
     :param use_verts: use 'verts' for splitting, else just find verts to split from edges
     :type use_verts: bool
-    :rtype: dict
     :return: - edges : old output disconnected edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -1505,7 +1458,6 @@ def subdivide_edgering(bm: 'bmesh.types.BMesh',
     :type profile_shape: typing.Union[str, int]
     :param profile_shape_factor: how much intermediary new edges are shrunk/expanded
     :type profile_shape_factor: float
-    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -1547,13 +1499,12 @@ def subdivide_edges(
     :type use_grid_fill: bool
     :param use_single_edge: tessellate the case of one edge selected in a quad or triangle
     :type use_single_edge: bool
-    :param use_only_quads: only subdivide quads (for loopcut)
+    :param use_only_quads: Only subdivide quads (for loop-cut).
     :type use_only_quads: bool
     :param use_sphere: for making new primitives only
     :type use_sphere: bool
     :param use_smooth_even: maintain even offset when smoothing
     :type use_smooth_even: bool
-    :rtype: dict
     :return: - geom_inner : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_split : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom : contains all output geometry **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1561,8 +1512,8 @@ def subdivide_edges(
 
 
 def symmetrize(bm: 'bmesh.types.BMesh',
-               input: typing.Union[typing.List['bmesh.types.BMVert'], typing.
-                                   List['bmesh.types.BMFace'], typing.
+               input: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                   List['bmesh.types.BMVert'], typing.
                                    List['bmesh.types.BMEdge']],
                direction: typing.Union[str, int], dist: float,
                use_shapekey: bool) -> dict:
@@ -1571,14 +1522,13 @@ def symmetrize(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: input geometry
-    :type input: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge']]
+    :type input: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge']]
     :param direction: axis to use
     :type direction: typing.Union[str, int]
     :param dist: minimum distance
     :type dist: float
     :param use_shapekey: Transform shape keys too.
     :type use_shapekey: bool
-    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1640,7 +1590,6 @@ def triangle_fill(bm: 'bmesh.types.BMesh', use_beauty: bool,
     :type edges: typing.List['bmesh.types.BMEdge']
     :param normal: optionally pass the fill normal to use
     :type normal: typing.List['mathutils.Vector']
-    :rtype: dict
     :return: - geom : new faces and edges **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1661,7 +1610,6 @@ def triangulate(bm: 'bmesh.types.BMesh',
     :type quad_method: typing.Union[str, int]
     :param ngon_method: method for splitting the polygons into triangles
     :type ngon_method: typing.Union[str, int]
-    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge ) - faces : **type** list of ( bmesh.types.BMFace ) - face_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - face_map_double : duplicate faces **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -1725,7 +1673,6 @@ def wireframe(bm: 'bmesh.types.BMesh',
     :type use_relative_offset: bool
     :param material_offset: offset material index of generated faces
     :type material_offset: int
-    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
