@@ -282,10 +282,10 @@ class BMEditSelIter:
 
 
 class BMEditSelSeq:
-    active: typing.Union['BMVert', 'BMFace', 'BMEdge'] = None
+    active: typing.Union['BMFace', 'BMVert', 'BMEdge'] = None
     ''' The last selected element or None (read-only).
 
-    :type: typing.Union['BMVert', 'BMFace', 'BMEdge']
+    :type: typing.Union['BMFace', 'BMVert', 'BMEdge']
     '''
 
     def add(self, element):
@@ -1290,15 +1290,12 @@ class BMesh:
     def from_object(self,
                     object: 'bpy.types.Object',
                     depsgraph,
-                    deform: bool = True,
                     cage: bool = False,
                     face_normals: bool = True):
-        ''' Initialize this bmesh from existing object datablock (currently only meshes are supported).
+        ''' Initialize this bmesh from existing object data-block (only meshes are currently supported).
 
         :param object: The object data to load.
         :type object: 'bpy.types.Object'
-        :param deform: Apply deformation modifiers.
-        :type deform: bool
         :param cage: Get the mesh as a deformed cage.
         :type cage: bool
         :param face_normals: Calculate face normals.
