@@ -82,7 +82,7 @@ def duplicate_move(ACTION_OT_duplicate=None, TRANSFORM_OT_transform=None):
 def easing_type(type: typing.Union[str, int] = 'AUTO'):
     ''' Set easing type for the F-Curve segments starting from the selected keyframes
 
-    :param type: Type * AUTO Automatic Easing, Easing type is chosen automatically based on what the type of interpolation used (e.g. 'Ease In' for transitional types, and 'Ease Out' for dynamic effects). * EASE_IN Ease In, Only on the end closest to the next keyframe. * EASE_OUT Ease Out, Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out, Segment between both keyframes.
+    :param type: Type * AUTO Automatic Easing, Easing type is chosen automatically based on what the type of interpolation used (e.g. Ease In for transitional types, and Ease Out for dynamic effects). * EASE_IN Ease In, Only on the end closest to the next keyframe. * EASE_OUT Ease Out, Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out, Segment between both keyframes.
     :type type: typing.Union[str, int]
     '''
 
@@ -140,7 +140,7 @@ def keyframe_insert(type: typing.Union[str, int] = 'ALL'):
 def keyframe_type(type: typing.Union[str, int] = 'KEYFRAME'):
     ''' Set type of keyframe for the selected keyframes
 
-    :param type: Type * KEYFRAME Keyframe, Normal keyframe, e.g. for key poses. * BREAKDOWN Breakdown, A breakdown pose, e.g. for transitions between key poses. * MOVING_HOLD Moving Hold, A keyframe that is part of a moving hold. * EXTREME Extreme, An 'extreme' pose, or some other purpose as needed. * JITTER Jitter, A filler or baked keyframe for keying on ones, or some other purpose as needed.
+    :param type: Type * KEYFRAME Keyframe, Normal keyframe, e.g. for key poses. * BREAKDOWN Breakdown, A breakdown pose, e.g. for transitions between key poses. * MOVING_HOLD Moving Hold, A keyframe that is part of a moving hold. * EXTREME Extreme, An "extreme" pose, or some other purpose as needed. * JITTER Jitter, A filler or baked keyframe for keying on ones, or some other purpose as needed.
     :type type: typing.Union[str, int]
     '''
 
