@@ -45,7 +45,7 @@ def channels_click(extend: bool = False, children_only: bool = False):
 
 
 def channels_collapse(all: bool = True):
-    ''' Collapse (i.e. close) all selected expandable animation channels
+    ''' Collapse (close) all selected expandable animation channels
 
     :param all: All, Collapse all channels (not just selected ones)
     :type all: bool
@@ -76,7 +76,7 @@ def channels_editable_toggle(mode: typing.Union[str, int] = 'TOGGLE',
 
 
 def channels_expand(all: bool = True):
-    ''' Expand (i.e. open) all selected expandable animation channels
+    ''' Expand (open) all selected expandable animation channels
 
     :param all: All, Expand all channels (not just selected ones)
     :type all: bool
@@ -495,14 +495,6 @@ def previewrange_set(xmin: int = 0,
     pass
 
 
-def show_group_colors_deprecated():
-    ''' This option moved to Preferences > Animation :file: startup/bl_operators/anim.py\:439 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/anim.py$439> _
-
-    '''
-
-    pass
-
-
 def start_frame_set():
     ''' Set the current frame as the preview or scene start frame
 
@@ -514,7 +506,7 @@ def start_frame_set():
 def update_animated_transform_constraints(use_convert_to_radians: bool = True):
     ''' Update f-curves/drivers affecting Transform constraints (use it with files from 2.70 and earlier)
 
-    :param use_convert_to_radians: Convert to Radians, Convert fcurves/drivers affecting rotations to radians (Warning: use this only once!)
+    :param use_convert_to_radians: Convert to Radians, Convert f-curves/drivers affecting rotations to radians. Warning: Use this only once
     :type use_convert_to_radians: bool
     '''
 
