@@ -122,7 +122,9 @@ def fbx(filepath: str = "",
     pass
 
 
-def gltf(export_format: typing.Union[str, int] = 'GLB',
+def gltf(filepath: str = "",
+         check_existing: bool = True,
+         export_format: typing.Union[str, int] = 'GLB',
          ui_tab: typing.Union[str, int] = 'GENERAL',
          export_copyright: str = "",
          export_image_format: typing.Union[str, int] = 'AUTO',
@@ -139,9 +141,14 @@ def gltf(export_format: typing.Union[str, int] = 'GLB',
          export_tangents: bool = False,
          export_materials: typing.Union[str, int] = 'EXPORT',
          export_colors: bool = True,
+         use_mesh_edges: bool = False,
+         use_mesh_vertices: bool = False,
          export_cameras: bool = False,
          export_selected: bool = False,
          use_selection: bool = False,
+         use_visible: bool = False,
+         use_renderable: bool = False,
+         use_active_collection: bool = False,
          export_extras: bool = False,
          export_yup: bool = True,
          export_apply: bool = False,
@@ -160,11 +167,13 @@ def gltf(export_format: typing.Union[str, int] = 'GLB',
          export_lights: bool = False,
          export_displacement: bool = False,
          will_save_settings: bool = False,
-         filepath: str = "",
-         check_existing: bool = True,
          filter_glob: str = "*.glb;*.gltf"):
     ''' Export scene as glTF 2.0 file
 
+    :param filepath: File Path, Filepath used for exporting the file
+    :type filepath: str
+    :param check_existing: Check Existing, Check and warn on overwriting existing files
+    :type check_existing: bool
     :param export_format: Format, Output format and embedding options. Binary is most efficient, but JSON (embedded or separate) may be easier to edit later * GLB glTF Binary (.glb), Exports a single file, with all data packed in binary form. Most efficient and portable, but more difficult to edit later. * GLTF_EMBEDDED glTF Embedded (.gltf), Exports a single file, with all data packed in JSON. Less efficient than binary, but easier to edit later. * GLTF_SEPARATE glTF Separate (.gltf + .bin + textures), Exports multiple files, with separate JSON, binary and texture data. Easiest to edit later.
     :type export_format: typing.Union[str, int]
     :param ui_tab: ui_tab, Export setting categories * GENERAL General, General settings. * MESHES Meshes, Mesh settings. * OBJECTS Objects, Object settings. * ANIMATION Animation, Animation settings.
@@ -199,12 +208,22 @@ def gltf(export_format: typing.Union[str, int] = 'GLB',
     :type export_materials: typing.Union[str, int]
     :param export_colors: Vertex Colors, Export vertex colors with meshes
     :type export_colors: bool
+    :param use_mesh_edges: Loose Edges, Export loose edges as lines, using the material from the first material slot
+    :type use_mesh_edges: bool
+    :param use_mesh_vertices: Loose Points, Export loose points as glTF points, using the material from the first material slot
+    :type use_mesh_vertices: bool
     :param export_cameras: Cameras, Export cameras
     :type export_cameras: bool
     :param export_selected: Selected Objects, Export selected objects only
     :type export_selected: bool
     :param use_selection: Selected Objects, Export selected objects only
     :type use_selection: bool
+    :param use_visible: Visible Objects, Export visible objects only
+    :type use_visible: bool
+    :param use_renderable: Renderable Objects, Export renderable objects only
+    :type use_renderable: bool
+    :param use_active_collection: Active Collection, Export objects in the active collection only
+    :type use_active_collection: bool
     :param export_extras: Custom Properties, Export custom properties as glTF extras
     :type export_extras: bool
     :param export_yup: +Y Up, Export using glTF convention, +Y up
@@ -241,10 +260,6 @@ def gltf(export_format: typing.Union[str, int] = 'GLB',
     :type export_displacement: bool
     :param will_save_settings: Remember Export Settings, Store glTF export settings in the Blender project
     :type will_save_settings: bool
-    :param filepath: File Path, Filepath used for exporting the file
-    :type filepath: str
-    :param check_existing: Check Existing, Check and warn on overwriting existing files
-    :type check_existing: bool
     :param filter_glob: filter_glob
     :type filter_glob: str
     '''
