@@ -428,11 +428,29 @@ def image_to_grease_pencil(size: float = 0.005, mask: bool = False):
     pass
 
 
-def interpolate(shift: float = 0.0):
+def interpolate(shift: float = 0.0,
+                layers: typing.Union[str, int] = 'ACTIVE',
+                interpolate_selected_only: bool = False,
+                flip: typing.Union[str, int] = 'AUTO',
+                smooth_steps: int = 1,
+                smooth_factor: float = 0.0,
+                release_confirm: bool = False):
     ''' Interpolate grease pencil strokes between frames
 
     :param shift: Shift, Bias factor for which frame has more influence on the interpolated strokes
     :type shift: float
+    :param layers: Layer, Layers included in the interpolation
+    :type layers: typing.Union[str, int]
+    :param interpolate_selected_only: Only Selected, Interpolate only selected strokes
+    :type interpolate_selected_only: bool
+    :param flip: Flip Mode, Invert destination stroke to match start and end with source stroke
+    :type flip: typing.Union[str, int]
+    :param smooth_steps: Iterations, Number of times to smooth newly created strokes
+    :type smooth_steps: int
+    :param smooth_factor: Smooth, Amount of smoothing to apply to interpolated strokes, to reduce jitter/noise
+    :type smooth_factor: float
+    :param release_confirm: Confirm on Release
+    :type release_confirm: bool
     '''
 
     pass
@@ -446,9 +464,41 @@ def interpolate_reverse():
     pass
 
 
-def interpolate_sequence():
+def interpolate_sequence(step: int = 1,
+                         layers: typing.Union[str, int] = 'ACTIVE',
+                         interpolate_selected_only: bool = False,
+                         flip: typing.Union[str, int] = 'AUTO',
+                         smooth_steps: int = 1,
+                         smooth_factor: float = 0.0,
+                         type: typing.Union[str, int] = 'LINEAR',
+                         easing: typing.Union[str, int] = 'AUTO',
+                         back: float = 1.702,
+                         amplitude: float = 0.15,
+                         period: float = 0.15):
     ''' Generate 'in-betweens' to smoothly interpolate between Grease Pencil frames
 
+    :param step: Step, Number of frames between generated interpolated frames
+    :type step: int
+    :param layers: Layer, Layers included in the interpolation
+    :type layers: typing.Union[str, int]
+    :param interpolate_selected_only: Only Selected, Interpolate only selected strokes
+    :type interpolate_selected_only: bool
+    :param flip: Flip Mode, Invert destination stroke to match start and end with source stroke
+    :type flip: typing.Union[str, int]
+    :param smooth_steps: Iterations, Number of times to smooth newly created strokes
+    :type smooth_steps: int
+    :param smooth_factor: Smooth, Amount of smoothing to apply to interpolated strokes, to reduce jitter/noise
+    :type smooth_factor: float
+    :param type: Type, Interpolation method to use the next time 'Interpolate Sequence' is run * LINEAR Linear, Straight-line interpolation between A and B (i.e. no ease in/out). * CUSTOM Custom, Custom interpolation defined using a curve map. * SINE Sinusoidal, Sinusoidal easing (weakest, almost linear but with a slight curvature). * QUAD Quadratic, Quadratic easing. * CUBIC Cubic, Cubic easing. * QUART Quartic, Quartic easing. * QUINT Quintic, Quintic easing. * EXPO Exponential, Exponential easing (dramatic). * CIRC Circular, Circular easing (strongest and most dynamic). * BACK Back, Cubic easing with overshoot and settle. * BOUNCE Bounce, Exponentially decaying parabolic bounce, like when objects collide. * ELASTIC Elastic, Exponentially decaying sine wave, like an elastic band.
+    :type type: typing.Union[str, int]
+    :param easing: Easing, Which ends of the segment between the preceding and following grease pencil frames easing interpolation is applied to * AUTO Automatic Easing, Easing type is chosen automatically based on what the type of interpolation used (e.g. 'Ease In' for transitional types, and 'Ease Out' for dynamic effects). * EASE_IN Ease In, Only on the end closest to the next keyframe. * EASE_OUT Ease Out, Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out, Segment between both keyframes.
+    :type easing: typing.Union[str, int]
+    :param back: Back, Amount of overshoot for 'back' easing
+    :type back: float
+    :param amplitude: Amplitude, Amount to boost elastic bounces for 'elastic' easing
+    :type amplitude: float
+    :param period: Period, Time between bounces for elastic easing
+    :type period: float
     '''
 
     pass
@@ -508,9 +558,11 @@ def layer_change(layer: typing.Union[str, int] = 'DEFAULT'):
     pass
 
 
-def layer_duplicate():
+def layer_duplicate(mode: typing.Union[str, int] = 'ALL'):
     ''' Make a copy of the active Grease Pencil layer
 
+    :param mode: Mode
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -921,7 +973,7 @@ def select_all(action: typing.Union[str, int] = 'TOGGLE'):
     pass
 
 
-def select_alternate(unselect_ends: bool = True):
+def select_alternate(unselect_ends: bool = False):
     ''' Select alternative points in same strokes as already selected points
 
     :param unselect_ends: Unselect Ends, Do not select the first and last point of the stroke
@@ -1123,7 +1175,7 @@ def stroke_apply_thickness():
 
 
 def stroke_arrange(direction: typing.Union[str, int] = 'UP'):
-    ''' Arrange selected strokes up/down in the drawing order of the active layer
+    ''' Arrange selected strokes up/down in the display order of the active layer
 
     :param direction: Direction
     :type direction: typing.Union[str, int]
@@ -1402,7 +1454,7 @@ def stroke_trim():
 
 
 def tint_flip():
-    ''' Switch tint colors :file: startup/bl_ui/properties_grease_pencil_common.py\:872 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_ui/properties_grease_pencil_common.py$872> _
+    ''' Switch tint colors :file: startup/bl_ui/properties_grease_pencil_common.py\:899 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_ui/properties_grease_pencil_common.py$899> _
 
     '''
 
@@ -1416,7 +1468,8 @@ def trace_image(target: typing.Union[str, int] = 'NEW',
                 sample: float = 0.0,
                 threshold: float = 0.5,
                 turnpolicy: typing.Union[str, int] = 'MINORITY',
-                mode: typing.Union[str, int] = 'SINGLE'):
+                mode: typing.Union[str, int] = 'SINGLE',
+                use_current_frame: bool = True):
     ''' Extract Grease Pencil strokes from image
 
     :param target: Target Object, Target grease pencil
@@ -1435,6 +1488,8 @@ def trace_image(target: typing.Union[str, int] = 'NEW',
     :type turnpolicy: typing.Union[str, int]
     :param mode: Mode, Determines if trace simple image or full sequence * SINGLE Single, Trace the current frame of the image. * SEQUENCE Sequence, Trace full sequence.
     :type mode: typing.Union[str, int]
+    :param use_current_frame: Start At Current Frame, Trace Image starting in current image frame
+    :type use_current_frame: bool
     '''
 
     pass
