@@ -92,7 +92,7 @@ def decimate(mode: typing.Union[str, int] = 'RATIO',
 
     :param mode: Mode, Which mode to use for decimation * RATIO Ratio, Use a percentage to specify how many keyframes you want to remove. * ERROR Error Margin, Use an error margin to specify how much the curve is allowed to deviate from the original path.
     :type mode: typing.Union[str, int]
-    :param remove_ratio: Remove, The percentage of keyframes to remove
+    :param remove_ratio: Remove, The ratio of remaining keyframes after the operation
     :type remove_ratio: float
     :param remove_error_margin: Max Error Margin, How much the new decimated curve is allowed to deviate from the original
     :type remove_error_margin: float
@@ -160,7 +160,7 @@ def duplicate_move(GRAPH_OT_duplicate=None, TRANSFORM_OT_transform=None):
 def easing_type(type: typing.Union[str, int] = 'AUTO'):
     ''' Set easing type for the F-Curve segments starting from the selected keyframes
 
-    :param type: Type * AUTO Automatic Easing, Easing type is chosen automatically based on what the type of interpolation used (e.g. 'Ease In' for transitional types, and 'Ease Out' for dynamic effects). * EASE_IN Ease In, Only on the end closest to the next keyframe. * EASE_OUT Ease Out, Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out, Segment between both keyframes.
+    :param type: Type * AUTO Automatic Easing, Easing type is chosen automatically based on what the type of interpolation used (e.g. Ease In for transitional types, and Ease Out for dynamic effects). * EASE_IN Ease In, Only on the end closest to the next keyframe. * EASE_OUT Ease Out, Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out, Segment between both keyframes.
     :type type: typing.Union[str, int]
     '''
 
