@@ -38,8 +38,8 @@ def stl(filepath: str = "",
         global_scale: float = 1.0,
         use_scene_unit: bool = False,
         use_facet_normal: bool = False,
-        axis_forward: typing.Union[int, str] = 'Y',
-        axis_up: typing.Union[int, str] = 'Z'):
+        axis_forward: typing.Union[str, int] = 'Y',
+        axis_up: typing.Union[str, int] = 'Z'):
     ''' Load STL triangle mesh data
 
     :param filepath: File Path, Filepath used for importing the file
@@ -57,9 +57,9 @@ def stl(filepath: str = "",
     :param use_facet_normal: Facet Normals, Use (import) facet normals (note that this will still give flat shading)
     :type use_facet_normal: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     '''
 
     pass
