@@ -2102,13 +2102,13 @@ def select_prev_item():
     pass
 
 
-def select_random(percent: float = 50.0,
+def select_random(ratio: float = 0.5,
                   seed: int = 0,
                   action: typing.Union[str, int] = 'SELECT'):
     ''' Randomly select vertices
 
-    :param percent: Percent, Percentage of objects to select randomly
-    :type percent: float
+    :param ratio: Ratio, Portion of items to select randomly
+    :type ratio: float
     :param seed: Random Seed, Seed for the random number generator
     :type seed: int
     :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
@@ -2265,7 +2265,7 @@ def sort_elements(
         seed: int = 0):
     ''' The order of selected vertices/edges/faces is modified, based on a given method
 
-    :param type: Type, Type of reordering operation to apply * VIEW_ZAXIS View Z Axis, Sort selected elements from farthest to nearest one in current view. * VIEW_XAXIS View X Axis, Sort selected elements from left to right one in current view. * CURSOR_DISTANCE Cursor Distance, Sort selected elements from nearest to farthest from 3D cursor. * MATERIAL Material, Sort selected elements from smallest to greatest material index (faces only!). * SELECTED Selected, Move all selected elements in first places, preserving their relative order (WARNING: this will affect unselected elements' indices as well!). * RANDOMIZE Randomize, Randomize order of selected elements. * REVERSE Reverse, Reverse current order of selected elements.
+    :param type: Type, Type of reordering operation to apply * VIEW_ZAXIS View Z Axis, Sort selected elements from farthest to nearest one in current view. * VIEW_XAXIS View X Axis, Sort selected elements from left to right one in current view. * CURSOR_DISTANCE Cursor Distance, Sort selected elements from nearest to farthest from 3D cursor. * MATERIAL Material, Sort selected faces from smallest to greatest material index. * SELECTED Selected, Move all selected elements in first places, preserving their relative order. Warning: This will affect unselected elements' indices as well. * RANDOMIZE Randomize, Randomize order of selected elements. * REVERSE Reverse, Reverse current order of selected elements.
     :type type: typing.Union[str, int]
     :param elements: Elements, Which elements to affect (vertices, edges and/or faces)
     :type elements: typing.Union[typing.Set[str], typing.Set[int]]
