@@ -4,6 +4,14 @@ import bl_operators.node
 import bpy.types
 
 
+def active_preview_toggle():
+    ''' Toggle active preview state of node :file: startup/bl_operators/node.py\:326 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/node.py$326> _
+
+    '''
+
+    pass
+
+
 def add_and_link_node(
         type: str = "",
         use_transform: bool = False,
@@ -27,6 +35,16 @@ def add_and_link_node(
     pass
 
 
+def add_collection(name: str = "Collection"):
+    ''' Add an collection info node to the current node editor
+
+    :param name: Name, Data-block name to assign
+    :type name: str
+    '''
+
+    pass
+
+
 def add_file(filepath: str = "",
              hide_props_region: bool = True,
              filter_blender: bool = False,
@@ -109,6 +127,16 @@ def add_file(filepath: str = "",
     pass
 
 
+def add_group(name: str = "Mask"):
+    ''' Add an existing node group to the current node editor
+
+    :param name: Name, Data-block name to assign
+    :type name: str
+    '''
+
+    pass
+
+
 def add_mask(name: str = "Mask"):
     ''' Add a mask node to the current node editor
 
@@ -138,6 +166,16 @@ def add_node(type: str = "",
     pass
 
 
+def add_object(name: str = "Object"):
+    ''' Add an object info node to the current node editor
+
+    :param name: Name, Data-block name to assign
+    :type name: str
+    '''
+
+    pass
+
+
 def add_reroute(path: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
         List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
@@ -175,6 +213,16 @@ def add_search(type: str = "",
     pass
 
 
+def add_texture(name: str = "Texture"):
+    ''' Add a texture to the current node editor
+
+    :param name: Name, Data-block name to assign
+    :type name: str
+    '''
+
+    pass
+
+
 def attach():
     ''' Attach active node to a frame
 
@@ -242,7 +290,15 @@ def clipboard_paste():
 
 
 def collapse_hide_unused_toggle():
-    ''' Toggle collapsed nodes and hide unused sockets :file: startup/bl_operators/node.py\:267 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/node.py$267> _
+    ''' Toggle collapsed nodes and hide unused sockets :file: startup/bl_operators/node.py\:271 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/node.py$271> _
+
+    '''
+
+    pass
+
+
+def copy_geometry_node_group_assign():
+    ''' Copy the active geometry node group and assign it to the active modifier :file: startup/bl_operators/geometry_nodes.py\:106 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/geometry_nodes.py$106> _
 
     '''
 
@@ -419,11 +475,17 @@ def join():
     pass
 
 
-def link(detach: bool = False):
+def link(detach: bool = False,
+         has_link_picked: bool = False,
+         drag_start: typing.List[float] = (0.0, 0.0)):
     ''' Use the mouse to create a link between two nodes
 
     :param detach: Detach, Detach and redirect existing links
     :type detach: bool
+    :param has_link_picked: Has Link Picked, The operation has placed a link. Only used for multi-input sockets, where the link is picked later
+    :type has_link_picked: bool
+    :param drag_start: Drag Start, The position of the mouse cursor at the start of the operation
+    :type drag_start: typing.List[float]
     '''
 
     pass
@@ -470,6 +532,21 @@ def links_detach():
     pass
 
 
+def links_mute(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+               cursor: int = 35):
+    ''' Use the mouse to mute links
+
+    :param path: Path
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :param cursor: Cursor
+    :type cursor: int
+    '''
+
+    pass
+
+
 def move_detach_links(NODE_OT_links_detach=None,
                       TRANSFORM_OT_translate=None,
                       NODE_OT_insert_offset=None):
@@ -503,7 +580,7 @@ def mute_toggle():
 
 
 def new_geometry_node_group_assign():
-    ''' Create a new geometry node group and assign it to the active modifier :file: startup/bl_operators/geometry_nodes.py\:82 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/geometry_nodes.py$82> _
+    ''' Create a new geometry node group and assign it to the active modifier :file: startup/bl_operators/geometry_nodes.py\:83 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/geometry_nodes.py$83> _
 
     '''
 
@@ -511,7 +588,7 @@ def new_geometry_node_group_assign():
 
 
 def new_geometry_nodes_modifier():
-    ''' Create a new modifier with a new geometry node group :file: startup/bl_operators/geometry_nodes.py\:62 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/geometry_nodes.py$62> _
+    ''' Create a new modifier with a new geometry node group :file: startup/bl_operators/geometry_nodes.py\:63 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/geometry_nodes.py$63> _
 
     '''
 
@@ -674,7 +751,7 @@ def select_box(tweak: bool = False,
                mode: typing.Union[str, int] = 'SET'):
     ''' Use box selection to select nodes
 
-    :param tweak: Tweak, Only activate when mouse is not over a node - useful for tweak gesture
+    :param tweak: Tweak, Only activate when mouse is not over a node (useful for tweak gesture)
     :type tweak: bool
     :param xmin: X Min
     :type xmin: int
@@ -736,7 +813,7 @@ def select_lasso(
         mode: typing.Union[str, int] = 'SET'):
     ''' Select nodes using lasso selection
 
-    :param tweak: Tweak, Only activate when mouse is not over a node - useful for tweak gesture
+    :param tweak: Tweak, Only activate when mouse is not over a node (useful for tweak gesture)
     :type tweak: bool
     :param path: Path
     :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
@@ -826,7 +903,7 @@ def translate_attach_remove_on_cancel(TRANSFORM_OT_translate=None,
 
 
 def tree_path_parent():
-    ''' Go to parent node tree :file: startup/bl_operators/node.py\:297 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/node.py$297> _
+    ''' Go to parent node tree :file: startup/bl_operators/node.py\:301 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/node.py$301> _
 
     '''
 
