@@ -73,7 +73,7 @@ def duplicate_particle_system(use_duplicate_settings: bool = False):
 
 
 def dupliob_copy():
-    ''' Duplicate the current dupliobject
+    ''' Duplicate the current instance object
 
     '''
 
@@ -81,7 +81,7 @@ def dupliob_copy():
 
 
 def dupliob_move_down():
-    ''' Move dupli object down in the list
+    ''' Move instance object down in the list
 
     '''
 
@@ -89,7 +89,7 @@ def dupliob_move_down():
 
 
 def dupliob_move_up():
-    ''' Move dupli object up in the list
+    ''' Move instance object up in the list
 
     '''
 
@@ -97,7 +97,7 @@ def dupliob_move_up():
 
 
 def dupliob_refresh():
-    ''' Refresh list of dupli objects and their weights
+    ''' Refresh list of instance objects and their weights
 
     '''
 
@@ -105,7 +105,7 @@ def dupliob_refresh():
 
 
 def dupliob_remove():
-    ''' Remove the selected dupliobject
+    ''' Remove the selected instance object
 
     '''
 
@@ -255,14 +255,14 @@ def select_more():
     pass
 
 
-def select_random(percent: float = 50.0,
+def select_random(ratio: float = 0.5,
                   seed: int = 0,
                   action: typing.Union[str, int] = 'SELECT',
                   type: typing.Union[str, int] = 'HAIR'):
     ''' Select a randomly distributed set of hair or points
 
-    :param percent: Percent, Percentage of objects to select randomly
-    :type percent: float
+    :param ratio: Ratio, Portion of items to select randomly
+    :type ratio: float
     :param seed: Random Seed, Seed for the random number generator
     :type seed: int
     :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
