@@ -180,7 +180,7 @@ def effect_strip_add(type: typing.Union[str, int] = 'CROSS',
     :type replace_sel: bool
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
-    :param color: Color, Initialize the strip with this color (only used when type='COLOR')
+    :param color: Color, Initialize the strip with this color
     :type color: typing.List[float]
     '''
 
@@ -357,6 +357,7 @@ def image_strip_add(
         replace_sel: bool = True,
         overlap: bool = False,
         fit_method: typing.Union[str, int] = 'FIT',
+        set_view_transform: bool = True,
         use_placeholders: bool = False):
     ''' Add an image or image sequence to the sequencer
 
@@ -420,6 +421,8 @@ def image_strip_add(
     :type overlap: bool
     :param fit_method: Fit Method, Scale fit method * FIT Scale to Fit, Scale image to fit within the canvas. * FILL Scale to Fill, Scale image to completely fill the canvas. * STRETCH Stretch to Fill, Stretch image to fill the canvas. * ORIGINAL Use Original Size, Keep image at its original size.
     :type fit_method: typing.Union[str, int]
+    :param set_view_transform: Set view transform, Set appropriate view transform based on media colorspace
+    :type set_view_transform: bool
     :param use_placeholders: Use Placeholders, Use placeholders for missing frames of the strip
     :type use_placeholders: bool
     '''
@@ -525,6 +528,7 @@ def movie_strip_add(
         replace_sel: bool = True,
         overlap: bool = False,
         fit_method: typing.Union[str, int] = 'FIT',
+        set_view_transform: bool = True,
         sound: bool = True,
         use_framerate: bool = True):
     ''' Add a movie strip to the sequencer
@@ -589,6 +593,8 @@ def movie_strip_add(
     :type overlap: bool
     :param fit_method: Fit Method, Scale fit method * FIT Scale to Fit, Scale image to fit within the canvas. * FILL Scale to Fill, Scale image to completely fill the canvas. * STRETCH Stretch to Fill, Stretch image to fill the canvas. * ORIGINAL Use Original Size, Keep image at its original size.
     :type fit_method: typing.Union[str, int]
+    :param set_view_transform: Set view transform, Set appropriate view transform based on media colorspace
+    :type set_view_transform: bool
     :param sound: Sound, Load sound with the movie
     :type sound: bool
     :param use_framerate: Use Movie Framerate, Use framerate from the movie to keep sound and video in sync
