@@ -93,11 +93,9 @@ def edittranslation_init():
     pass
 
 
-def eyedropper_color(use_accumulate: bool = True):
+def eyedropper_color():
     ''' Sample a color from the Blender window to store in a property
 
-    :param use_accumulate: Accumulate
-    :type use_accumulate: bool
     '''
 
     pass
