@@ -4,12 +4,12 @@ import bpy.types
 
 
 def abspath(path,
-            start: typing.Union[bytes, str] = None,
+            start: typing.Union[str, bytes] = None,
             library: 'bpy.types.Library' = None):
     ''' Returns the absolute path relative to the current blend file using the "//" prefix.
 
     :param start: Relative to this path, when not set the current filename is used.
-    :type start: typing.Union[bytes, str]
+    :type start: typing.Union[str, bytes]
     :param library: The library this path is from. This is only included for convenience, when the library is not None its path replaces *start*.
     :type library: 'bpy.types.Library'
     '''
@@ -33,8 +33,8 @@ def clean_name(name, replace='_'):
     pass
 
 
-def display_name(name, *, has_ext=True):
-    ''' Creates a display string from name to be used menus and the user interface. Capitalize the first letter in all lowercase names, mixed case names are kept as is. Intended for use with filenames and module names.
+def display_name(name, *, has_ext=True, title_case=True):
+    ''' Creates a display string from name to be used menus and the user interface. Intended for use with filenames and module names.
 
     '''
 
@@ -69,11 +69,11 @@ def ensure_ext(filepath, ext: str, case_sensitive: bool = False):
     pass
 
 
-def is_subdir(path: typing.Union[bytes, str], directory):
+def is_subdir(path: typing.Union[str, bytes], directory):
     ''' Returns true if *path* in a subdirectory of *directory*. Both paths must be absolute.
 
     :param path: An absolute path.
-    :type path: typing.Union[bytes, str]
+    :type path: typing.Union[str, bytes]
     '''
 
     pass
@@ -86,7 +86,6 @@ def module_names(path: str, recursive: bool = False) -> list:
     :type path: str
     :param recursive: Also return submodule names for packages.
     :type recursive: bool
-    :rtype: list
     :return: a list of string pairs (module_name, module_file).
     '''
 
@@ -106,21 +105,20 @@ def reduce_dirs(dirs: list) -> list:
 
     :param dirs: Sequence of directory paths.
     :type dirs: list
-    :rtype: list
     :return: A unique list of paths.
     '''
 
     pass
 
 
-def relpath(path: typing.Union[bytes, str],
-            start: typing.Union[bytes, str] = None):
+def relpath(path: typing.Union[str, bytes],
+            start: typing.Union[str, bytes] = None):
     ''' Returns the path relative to the current blend file using the "//" prefix.
 
     :param path: An absolute path.
-    :type path: typing.Union[bytes, str]
+    :type path: typing.Union[str, bytes]
     :param start: Relative to this path, when not set the current filename is used.
-    :type start: typing.Union[bytes, str]
+    :type start: typing.Union[str, bytes]
     '''
 
     pass
