@@ -3,8 +3,8 @@ import typing
 import bpy.types
 import bpy.context
 
-from . import previews
 from . import units
+from . import previews
 
 
 def app_template_paths(subdir: str = None):
@@ -29,7 +29,6 @@ def blend_paths(absolute: bool = False,
     :type packed: bool
     :param local: When true skip linked library paths.
     :type local: bool
-    :rtype: list
     :return: path list.
     '''
 
@@ -41,16 +40,19 @@ def escape_identifier(string: str) -> str:
 
     :param string: text
     :type string: str
-    :rtype: str
     :return: The escaped string.
     '''
 
     pass
 
 
-def execfile(filepath, mod=None):
-    ''' 
+def execfile(filepath: str, mod=None):
+    ''' Execute a file path as a Python script.
 
+    :param filepath: Path of the script to execute.
+    :type filepath: str
+    :param mod: Optional cached module, the result of a previous execution.
+    :return: The module which can be passed back in as mod .
     '''
 
     pass
@@ -101,7 +103,6 @@ def make_rna_paths(struct_name: str, prop_name: str, enum_name: str) -> tuple:
     :type prop_name: str
     :param enum_name: Name of a RNA enum identifier.
     :type enum_name: str
-    :rtype: tuple
     :return: A triple of three "RNA paths" (most_complete_path, "struct.prop", "struct.prop:'enum'"). If no enum_name is given, the third element will always be void.
     '''
 
@@ -123,7 +124,6 @@ def modules_from_path(path: str, loaded_modules: set) -> list:
     :type path: str
     :param loaded_modules: already loaded module names, files matching these names will be ignored.
     :type loaded_modules: set
-    :rtype: list
     :return: all loaded modules.
     '''
 
@@ -143,7 +143,6 @@ def preset_paths(subdir: str) -> list:
 
     :param subdir: preset subdirectory (must not be an absolute path).
     :type subdir: str
-    :rtype: list
     :return: script paths.
     '''
 
@@ -191,7 +190,6 @@ def register_submodule_factory(module_name: str,
     :type module_name: str
     :param submodule_names: List of submodule names to load and unload.
     :type submodule_names: list
-    :rtype: tuple
     :return: register and unregister functions.
     '''
 
@@ -231,7 +229,6 @@ def resource_path(type: str,
     :type major: int
     :param minor: minor version, defaults to current.
     :type minor: str
-    :rtype: str
     :return: the resource path (not necessarily existing).
     '''
 
@@ -266,7 +263,6 @@ def script_paths(subdir: str = None,
     :type user_pref: bool
     :param check_all: Include local, user and system paths rather just the paths blender uses.
     :type check_all: bool
-    :rtype: list
     :return: script paths.
     '''
 
@@ -278,20 +274,18 @@ def smpte_from_frame(frame: int, fps=None, fps_base=None) -> str:
 
     :param frame: frame number.
     :type frame: int
-    :rtype: str
     :return: the frame string.
     '''
 
     pass
 
 
-def smpte_from_seconds(time: typing.Union[int, float], fps=None,
+def smpte_from_seconds(time: typing.Union[float, int], fps=None,
                        fps_base=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: HH:MM:SS:FF . If *fps* and *fps_base* are not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: typing.Union[int, float]
-    :rtype: str
+    :type time: typing.Union[float, int]
     :return: the frame string.
     '''
 
@@ -319,7 +313,6 @@ def unescape_identifier(string: str) -> str:
 
     :param string: text
     :type string: str
-    :rtype: str
     :return: The un-escaped string.
     '''
 
@@ -359,7 +352,6 @@ def user_resource(resource_type, path='', create: bool = False) -> str:
     :type subdir: str
     :param create: Treat the path as a directory and create it if its not existing.
     :type create: bool
-    :rtype: str
     :return: a path.
     '''
 
