@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class ImagePreviewCollection:
     ''' Dictionary-like class of previews. This is a subclass of Python's built-in dict type, used to store multiple image previews.
@@ -22,31 +20,30 @@ class ImagePreviewCollection:
         pass
 
     def load(self,
-             name: typing.Optional[str],
-             filepath: typing.Optional[str],
-             filetype: typing.Optional[str],
-             force_reload: typing.Optional[bool] = False
-             ) -> 'bpy.types.ImagePreview':
-        ''' Generate a new preview from given file path, or return existing one matching ``name``.
+             name: str,
+             filepath: str,
+             filetype: str,
+             force_reload: bool = False) -> 'bpy.types.ImagePreview':
+        ''' Generate a new preview from given file path. :raises KeyError: if name already exists.
 
         :param name: The name (unique id) identifying the preview.
-        :type name: typing.Optional[str]
+        :type name: str
         :param filepath: The file path to generate the preview from.
-        :type filepath: typing.Optional[str]
+        :type filepath: str
         :param filetype: The type of file, needed to generate the preview in ['IMAGE', 'MOVIE', 'BLEND', 'FONT'].
-        :type filetype: typing.Optional[str]
+        :type filetype: str
         :param force_reload: If True, force running thumbnail manager even if preview already exists in cache.
-        :type force_reload: typing.Optional[bool]
+        :type force_reload: bool
         :rtype: 'bpy.types.ImagePreview'
         :return: The Preview matching given name, or a new empty one.
         '''
         pass
 
-    def new(self, name: typing.Optional[str]) -> 'bpy.types.ImagePreview':
-        ''' Generate a new empty preview, or return existing one matching ``name``.
+    def new(self, name: str) -> 'bpy.types.ImagePreview':
+        ''' Generate a new empty preview. :raises KeyError: if name already exists.
 
         :param name: The name (unique id) identifying the preview.
-        :type name: typing.Optional[str]
+        :type name: str
         :rtype: 'bpy.types.ImagePreview'
         :return: The Preview matching given name, or a new empty one.
         '''
@@ -56,18 +53,17 @@ class ImagePreviewCollection:
 def new() -> 'ImagePreviewCollection':
     ''' 
 
-    :rtype: 'ImagePreviewCollection'
     :return: a new preview collection.
     '''
 
     pass
 
 
-def remove(pcoll: typing.Optional['ImagePreviewCollection']):
+def remove(pcoll: 'ImagePreviewCollection'):
     ''' Remove the specified previews collection.
 
     :param pcoll: Preview collection to close.
-    :type pcoll: typing.Optional['ImagePreviewCollection']
+    :type pcoll: 'ImagePreviewCollection'
     '''
 
     pass
