@@ -50,7 +50,6 @@ def axis_conversion_ensure(operator: 'bpy.types.Operator', forward_attr: str,
     :type forward_attr: str
     :param up_attr: attribute storing the up axis
     :type up_attr: str
-    :rtype: bool
     :return: True if the value was modified.
     '''
 
@@ -104,7 +103,6 @@ def path_reference(filepath: str,
     :type copy_set: set
     :param library: The library this path is relative to.
     :type library: 'bpy.types.Library'
-    :rtype: str
     :return: the new filepath.
     '''
 
@@ -158,8 +156,3 @@ def unpack_list(list_of_tuples):
     '''
 
     pass
-
-
-path_reference_mode = None
-''' constant value (<built-in function EnumProperty>, {'name': 'Path Mode', 'description': 'Method used to reference paths', 'items': (('AUTO', 'Auto', 'Use Relative paths with subdirectories only'), ('ABSOLUTE', 'Absolute', 'Always write absolute paths'), ('RELATIVE', 'Relative', 'Always write relative paths (where possible)'), ('MATCH', 'Match', 'Match Absolute/Relative setting with input path'), ('STRIP', 'Strip Path', 'Filename only'), ('COPY', 'Copy', 'Copy the file to the destination path (or subdirectory)')), 'default': 'AUTO', 'attr': 'path_mode'})
-'''
