@@ -2,12 +2,10 @@ import sys
 import typing
 import gpu.types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def batch_for_shader(shader: 'gpu.types.GPUShader',
                      type: str,
-                     content: typing.Dict,
+                     content: dict,
                      indices=None):
     ''' Return a batch already configured and compatible with the shader.
 
@@ -16,7 +14,7 @@ def batch_for_shader(shader: 'gpu.types.GPUShader',
     :param type: "'POINTS', 'LINES', 'TRIS' or 'LINES_ADJ'".
     :type type: str
     :param content: Maps the name of the shader attribute with the data to fill the vertex buffer.
-    :type content: typing.Dict
+    :type content: dict
     :return: compatible batch
     '''
 
