@@ -39,7 +39,6 @@ def barycentric_transform(
     :type tri_b2: 'mathutils.Vector'
     :param tri_b3: target triangle vertex.
     :type tri_b3: 'mathutils.Vector'
-    :rtype: 'mathutils.Vector'
     :return: The transformed point
     '''
 
@@ -51,7 +50,6 @@ def box_fit_2d(points: list) -> float:
 
     :param points: list of 2d points.
     :type points: list
-    :rtype: float
     :return: angle
     '''
 
@@ -63,7 +61,6 @@ def box_pack_2d(boxes: list) -> tuple:
 
     :param boxes: list of boxes, each box is a list where the first 4 items are [x, y, width, height, ...] other items are ignored.
     :type boxes: list
-    :rtype: tuple
     :return: the width and height of the packed bounding box
     '''
 
@@ -83,7 +80,6 @@ def closest_point_on_tri(pt: 'mathutils.Vector', tri_p1: 'mathutils.Vector',
     :type tri_p2: 'mathutils.Vector'
     :param tri_p3: Third point of the triangle
     :type tri_p3: 'mathutils.Vector'
-    :rtype: 'mathutils.Vector'
     :return: The closest point of the triangle.
     '''
 
@@ -95,7 +91,6 @@ def convex_hull_2d(points: list) -> list:
 
     :param points: list of 2d points.
     :type points: list
-    :rtype: list
     :return: a list of indices
     '''
 
@@ -116,7 +111,6 @@ def delaunay_2d_cdt(
     :type faces: typing.List[int]
     :param output_type: What output looks like. 0 => triangles with convex hull. 1 => triangles inside constraints. 2 => the input constraints, intersected. 3 => like 2 but with extra edges to make valid BMesh faces.
     :type epsilon: float
-    :rtype: typing.Union[typing.List[int], typing.List['mathutils.Vector']]
     :return: Output tuple, (vert_coords, edges, faces, orig_verts, orig_edges, orig_faces)
     '''
 
@@ -154,7 +148,6 @@ def interpolate_bezier(knot1: 'mathutils.Vector', handle1: 'mathutils.Vector',
     :type knot2: 'mathutils.Vector'
     :param resolution: Number of points to return.
     :type resolution: int
-    :rtype: 'mathutils.Vector'
     :return: The interpolated points
     '''
 
@@ -192,7 +185,6 @@ def intersect_line_line_2d(lineA_p1: 'mathutils.Vector',
     :type lineB_p1: 'mathutils.Vector'
     :param lineB_p2: Second point of the second line
     :type lineB_p2: 'mathutils.Vector'
-    :rtype: 'mathutils.Vector'
     :return: The point of intersection or None when not found
     '''
 
@@ -214,7 +206,6 @@ def intersect_line_plane(line_a: 'mathutils.Vector',
     :type plane_co: 'mathutils.Vector'
     :param plane_no: The direction the plane is facing
     :type plane_no: 'mathutils.Vector'
-    :rtype: 'mathutils.Vector'
     :return: The point of intersection or None when not found
     '''
 
@@ -235,7 +226,6 @@ def intersect_line_sphere(line_a: 'mathutils.Vector',
     :param sphere_co: The center of the sphere
     :type sphere_co: 'mathutils.Vector'
     :param sphere_radius: Radius of the sphere
-    :rtype: 'mathutils.Vector'
     :return: The intersection points as a pair of vectors or None when there is no intersection
     '''
 
@@ -256,7 +246,6 @@ def intersect_line_sphere_2d(line_a: 'mathutils.Vector',
     :param sphere_co: The center of the sphere
     :type sphere_co: 'mathutils.Vector'
     :param sphere_radius: Radius of the sphere
-    :rtype: 'mathutils.Vector'
     :return: The intersection points as a pair of vectors or None when there is no intersection
     '''
 
@@ -277,7 +266,6 @@ def intersect_plane_plane(
     :type plane_b_co: 'mathutils.Vector'
     :param plane_b_no: Normal of the second plane
     :type plane_b_no: 'mathutils.Vector'
-    :rtype: 'mathutils.Vector'
     :return: The line of the intersection represented as a point and a vector
     '''
 
@@ -333,7 +321,6 @@ def intersect_point_tri(pt: 'mathutils.Vector', tri_p1: 'mathutils.Vector',
     :type tri_p2: 'mathutils.Vector'
     :param tri_p3: Third point of the triangle
     :type tri_p3: 'mathutils.Vector'
-    :rtype: 'mathutils.Vector'
     :return: Point on the triangles plane or None if its outside the triangle
     '''
 
@@ -378,7 +365,6 @@ def intersect_ray_tri(v1: 'mathutils.Vector',
     :type orig: 'mathutils.Vector'
     :param clip: When False, don't restrict the intersection to the area of the triangle, use the infinite plane defined by the triangle.
     :type clip: bool
-    :rtype: 'mathutils.Vector'
     :return: The point of intersection or None if no intersection is found
     '''
 
